@@ -41,7 +41,7 @@ bool KolabHelpers::checkForErrors(const Akonadi::Item &item)
     QString errorMsg;
     foreach (const Kolab::ErrorHandler::Err &error, Kolab::ErrorHandler::instance().getErrors()) {
         errorMsg.append(error.message);
-        errorMsg.append(QLatin1String("\n"));
+        errorMsg.append(QLatin1Char('\n'));
     }
 
     qCWarning(KOLABRESOURCE_LOG) << "Error on item with id: " << item.id() << " remote id: " << item.remoteId() << ":\n" << errorMsg;
@@ -446,7 +446,7 @@ void KolabHelpers::setFolderTypeAnnotation(QMap< QByteArray, QByteArray > &annot
 
 QColor KolabHelpers::getFolderColor(const QMap<QByteArray, QByteArray> &annotations)
 {
-    // kolab saves the color without a "#", so we need to add it to the rgb string to have a propper QColor
+    // kolab saves the color without a "#", so we need to add it to the rgb string to have a proper QColor
     if (annotations.contains("/shared" KOLAB_COLOR_ANNOTATION) && !annotations.value("/shared" KOLAB_COLOR_ANNOTATION).isEmpty()) {
         return QColor(QStringLiteral("#").append(QString::fromUtf8(annotations.value("/shared" KOLAB_COLOR_ANNOTATION))));
     } else if (annotations.contains("/private" KOLAB_COLOR_ANNOTATION) && !annotations.value("/private" KOLAB_COLOR_ANNOTATION).isEmpty()) {
